#iTerm Color Schemes#

- [Intro](#intro)
- [Installation Instructions](#installation-instructions)
- [Contribute](#contribute)
- [Screenshots](#screenshots)
- [Credits](#credits)
- [Extra](#extra)
  - [X11 Installation](#x11-installation)
  - [Konsole color schemes](#konsole-color-schemes)
  - [Terminator color schemes](#terminator-color-schemes)
  - [Mac OS Terminal color schemes](#terminal-color-schemes)
  - [Previewing color schemes](#previewing-color-schemes)

##Intro##
This is a set of color schemes for iTerm (aka iTerm2). Screenshots below and in the [screenshots](screenshots/) directory.

##Installation Instructions##
To install:

* Launch iTerm 2. Get the latest version at <a href="http://www.iterm2.com">iterm2.com</a>
* Type CMD+i (⌘+i)
* Navigate to Colors tab
* Click on Load Presets
* Click on Import
* Select the .itermcolors file(s) of the scheme(s) you'd like to use
* Click on Load Presets and choose a color scheme

##Contribute##
Have a great iTerm theme? Send it to me via a Pull Request! To export your theme settings:

* Launch iTerm 2
* Type CMD+i (⌘+i)
* Navigate to Colors tab
* Click on Load Presets
* Click on Export
* Save the .itermcolors file

To include a screenshot, please generate the output using the [screenshotTable.sh script](tools/screenshotTable.sh) in the ```tools``` directory.

**For screenshot consistency, please have your font set to 13pt Monaco and no transparency on the window**

##Screenshots##
###3024 Day###

![Screenshot](screenshots/3024_day.png)

###3024 Night###

![Screenshot](screenshots/3024_night.png)

###AdventureTime###

![Screenshot](screenshots/adventure_time.png)

###Afterglow###

![Screenshot](screenshots/afterglow.png)

###AlienBlood###

![Screenshot](screenshots/alien_blood.png)

###Argonaut###

![Screenshot](screenshots/argonaut.png)

###Arthur###

![Screenshot](screenshots/arthur.png)

###AtelierSulphurpool###

![Screenshot](screenshots/atelier-sulphurpool_dark.png)

###Atom###

![Screenshot](screenshots/atom.png)

###Atom One Light###

![Screenshot](screenshots/atom_one_light.png)

###Batman###

![Screenshot](screenshots/batman.png)

###Belafonte Day###

![Screenshot](screenshots/belafonte_day.png)

###Belafonte Night###

![Screenshot](screenshots/belafonte_night.png)

###BirdsOfParadise###

![Screenshot](screenshots/birds_of_paradise.png)

###Blazer###

![Screenshot](screenshots/blazer.png)

###Borland###

![Screenshot](screenshots/borland.png)

###Bright Lights###

![Screenshot](screenshots/bright_lights.png)

###Broadcast###

![Screenshot](screenshots/broadcast.png)

###Brogrammer###

![Screenshot](screenshots/brogrammer.png)

###C64###

![Screenshot](screenshots/c64.png)

###Chalk###

![Screenshot](screenshots/chalk.png)

###Chalkboard###

![Screenshot](screenshots/chalkboard.png)

###Ciapre###

![Screenshot](screenshots/ciapre.png)

###CLRS###

![Screenshot](screenshots/clrs.png)

###Cobalt Neon###

![Screenshot](screenshots/cobalt_neon.png)

###Cobalt2###

![Screenshot](screenshots/cobalt2.png)

###CrayonPonyFish###

![Screenshot](screenshots/crayon_pony_fish.png)

###Dark Pastel###

![Screenshot](screenshots/dark_pastel.png)

###Darkside###

![Screenshot](screenshots/darkside.png)

###Desert###

![Screenshot](screenshots/desert.png)

###DimmedMonokai###

![Screenshot](screenshots/dimmed_monokai.png)

###DotGov###

![Screenshot](screenshots/dot_gov.png)

###Dracula###

![Screenshot](screenshots/dracula.png)

###Duotone Dark###

![Screenshot](screenshots/duotone_dark.png)

###Earthsong###

![Screenshot](screenshots/earthsong.png)

###Elemental###

![Screenshot](screenshots/elemental.png)

###ENCOM###

![Screenshot](screenshots/encom.png)

###Espresso###

![Screenshot](screenshots/espresso.png)

###Espresso Libre###

![Screenshot](screenshots/espresso_libre.png)

###Fideloper###

![Screenshot](screenshots/fideloper.png)

###FishTank###

![Screenshot](screenshots/fish_tank.png)

###Flat###

![Screenshot](screenshots/flat.png)

###Flatland###

![Screenshot](screenshots/flatland.png)

###Floraverse###

![Screenshot](screenshots/floraverse.png)

###FrontEndDelight###

![Screenshot](screenshots/front_end_delight.png)

###FunForrest###

![Screenshot](screenshots/fun_forrest.png)

###Galaxy###

![Screenshot](screenshots/galaxy.png)

###Github###

![Screenshot](screenshots/github.png)

##Glacier###

![Screenshot](screenshots/glacier.png)

###Grape###

![Screenshot](screenshots/grape.png)

###Grass###

![Screenshot](screenshots/grass.png)

###Hardcore###

![Screenshot](screenshots/hardcore.png)

###Harper###

![Screenshot](screenshots/harper.png)

###Highway###

![Screenshot](screenshots/highway.png)

###Hipster Green###

![Screenshot](screenshots/hipster_green.png)

###Homebrew###

![Screenshot](screenshots/homebrew.png)

###Hurtado###

![Screenshot](screenshots/hurtado.png)

###Hybrid###

![Screenshot](screenshots/hybrid.png)

###IC_Green_PPL###

![Screenshot](screenshots/ic_green_ppl.png)

###IC_Orange_PPL###

![Screenshot](screenshots/ic_orange_ppl.png)

###idleToes###

![Screenshot](screenshots/idleToes.png)

###IR_Black###

![Screenshot](screenshots/ir_black.png)

###Jackie Brown###

![Screenshot](screenshots/jackie_brown.png)

###Japanesque###

![Screenshot](screenshots/japanesque.png)

###Jellybeans###

![Screenshot](screenshots/jellybeans.png)

###JetBrains Darcula###

![Screenshot](screenshots/jetbrains_darcula.png)

###Kibble###

![Screenshot](screenshots/kibble.png)

###Later This Evening ###

![Screenshot](screenshots/later_this_evening.png)

###Lavandula###

![Screenshot](screenshots/lavandula.png)

###LiquidCarbon###

![Screenshot](screenshots/liquid_carbon.png)

###LiquidCarbonTransparent###

![Screenshot](screenshots/liquid_carbon_transparent.png)

###LiquidCarbonTransparentInverse###

![Screenshot](screenshots/liquid_carbon_transparent_inverse.png)

###Man Page###

![Screenshot](screenshots/man_page.png)

###Material###

![Screenshot](screenshots/material.png)

###MaterialDark###

![Screenshot](screenshots/material_dark.png)

###Mathias###

![Screenshot](screenshots/mathias.png)

###Medallion###

![Screenshot](screenshots/medallion.png)

###Misterioso###

![Screenshot](screenshots/misterioso.png)

###Molokai###

![Screenshot](screenshots/molokai.png)

###MonaLisa###

![Screenshot](screenshots/mona_lisa.png)

###Monokai Soda###

![Screenshot](screenshots/monokai_soda.png)

###N0tch2k###

![Screenshot](screenshots/n0tch2k.png)

###Neopolitan###

![Screenshot](screenshots/neopolitan.png)

###Neutron###

![Screenshot](screenshots/neutron.png)


###NightLion v1###

![Screenshot](screenshots/nightlion_v1.png)

###NightLion v2###

![Screenshot](screenshots/nightlion_v2.png)

###Novel###

![Screenshot](screenshots/novel.png)

###Obsidian###

![Screenshot](screenshots/obsidian.png)

###Ocean###

![Screenshot](screenshots/ocean.png)


###OceanicMaterial###

![Screenshot](screenshots/oceanic_material.png)

###Ollie###

![Screenshot](screenshots/ollie.png)

###Parasio Dark###

![Screenshot](screenshots/paraiso_dark.png)

###PaulMillr###

![Screenshot](screenshots/paul_millr.png)

###Pencil Dark###

![Screenshot](screenshots/pencil_dark.png)

###Pencil Light###

![Screenshot](screenshots/pencil_light.png)

###Piatto Light###

![Screenshot](screenshots/piatto_light.png)

###Pnevma###

![Screenshot](screenshots/pnevma.png)

###Pro###

![Screenshot](screenshots/pro.png)

###Red Alert###

![Screenshot](screenshots/red_alert.png)

###Red Sands###

![Screenshot](screenshots/red_sands.png)

###Rippedcasts###

![Screenshot](screenshots/rippedcasts.png)

###Royal###

![Screenshot](screenshots/royal.png)

###Seafoam Pastel###

![Screenshot](screenshots/seafoam_pastel.png)

###SeaShells###

![Screenshot](screenshots/sea_shells.png)

###Seti###

![Screenshot](screenshots/seti.png)

###Shaman###

![Screenshot](screenshots/shaman.png)

###Slate###

![Screenshot](screenshots/slate.png)

###Smyck###

![Screenshot](screenshots/smyck.png)

###SoftServer###

![Screenshot](screenshots/soft_server.png)

###Solarized Darcula (With background image)###

![Screenshot](screenshots/solarized_darcula_with_background.png)

###Solarized Darcula (Without background image)###

![Screenshot](screenshots/solarized_darcula.png)

###Solarized Dark###

![Screenshot](screenshots/solarized_dark.png)

###Solarized Dark - Patched###

Some applications assume the ANSI color code 8 is a gray color. Solarized treats
this code as equal to the background. This theme is for people who prefer the
former. See issues [#59][issue-59], [#62][issue-62], and [#63][issue-63] for
more information.

![Screenshot](screenshots/solarized_dark_patched.png)

[issue-59]: https://github.com/mbadolato/iTerm2-Color-Schemes/issues/59
[issue-62]: https://github.com/mbadolato/iTerm2-Color-Schemes/issues/62
[issue-63]: https://github.com/mbadolato/iTerm2-Color-Schemes/issues/63

###Solarized Dark Higher Contrast###

![Screenshot](screenshots/solarized_dark_higher_contrast.png)

###Solarized Light###

![Screenshot](screenshots/solarized_light.png)

###SpaceGray###

![Screenshot](screenshots/space_gray.png)

###SpaceGray Eighties###

![Screenshot](screenshots/spacegray_eighties.png)

###SpaceGray Eighties Dull###

![Screenshot](screenshots/spacegray_eighties_dull.png)

###Spacedust###

![Screenshot](screenshots/spacedust.png)

###Spiderman###

![Screenshot](screenshots/spiderman.png)

###Spring###

![Screenshot](screenshots/spring.png)

###Square###

![Screenshot](screenshots/square.png)

###Sundried###

![Screenshot](screenshots/sundried.png)

###Symfonic###

![Screenshot](screenshots/symfonic.png)

###Teerb###

![Screenshot](screenshots/teerb.png)

###Terminal Basic###

![Screenshot](screenshots/terminal_basic.png)

###Thayer Bright###

![Screenshot](screenshots/thayer_bright.png)

###The Hulk###

![Screenshot](screenshots/the_hulk.png)

###Tomorrow###

![Screenshot](screenshots/tomorrow.png)

###Tomorrow Night###

![Screenshot](screenshots/tomorrow_night.png)

###Tomorrow Night Blue###

![Screenshot](screenshots/tomorrow_night_blue.png)

###Tomorrow Night Bright###

![Screenshot](screenshots/tomorrow_night_bright.png)

###Tomorrow Night Eighties###

![Screenshot](screenshots/tomorrow_night_eighties.png)

###ToyChest###

![Screenshot](screenshots/toy_chest.png)

###Treehouse###

![Screenshot](screenshots/treehouse.png)

###Twilight###

![Screenshot](screenshots/twilight.png)

###Ubuntu###

![Screenshot](screenshots/ubuntu.png)

###Urple###

![Screenshot](screenshots/urple.png)

###Vaughn###

![Screenshot](screenshots/vaughn.png)

###VibrantInk###

![Screenshot](screenshots/vibrant_ink.png)

###WarmNeon###

![Screenshot](screenshots/warm_neon.png)

###Wez###

![Screenshot](screenshots/wez.png)

###WildCherry###

![Screenshot](screenshots/wild_cherry.png)

###Wombat###

![Screenshot](screenshots/wombat.png)

###Wryan###

![Screenshot](screenshots/wryan.png)

###Zenburn###

![Screenshot](screenshots/zenburn.png)

## Credits
The schemes Novel, Espresso, Grass, Homebrew, Ocean, Pro, Man Page, Red Sands, and Terminal Basic are ports of the schemes of the same name included with the Mac Terminal application. All of Terminal's schemes have now been ported, with the excption of "Solid Colors" (random backgrounds, which iTerm doesn't support) and "Aerogel" (which is hideous).

The scheme idleToes was inspired by the [idleFingers](http://idlefingers.co.uk/) TextMate theme and suggested for inclusion by Seth Wilson.

The scheme Zenburn was inspired by the [Zenburn](http://snk.tuxfamily.org/log/zenburn-terminal-color-scheme.html) version created by Suraj N. Kurapati.

The scheme Symfonic was inspired by the color scheme used in the [documentation](http://symfony.com/doc/current/book/index.html) for the [Symfony](http://www.symfony.com) PHP Framework.

The scheme Github was inspired by the color theme palette used at [Github](http://github.com/) for their UI and in some of their mascot images.

The scheme Solarized Darcula was inspired by the color theme created by [@rickhanlonii](https://github.com/rickhanlonii). There are two screenshots below; one with a background and one without. The background image is included in the backgrounds/ directory and the image must be manually set on the profile's Preferences->Window tab. It's hard to see from the screenshot, but it looks great!

The theme Hurtado was found [here](https://github.com/juanghurtado/dotfiles).

The theme Molokai was based on the [vim colorscheme](https://github.com/tomasr/molokai) of the same name.

The theme Monokai Soda was found [here](https://github.com/deepsweet/Monokai-Soda-iTerm).

The theme Neopolitan was created by [daytonn](https://github.com/daytonn/iTerm2-Color-Schemes)

The themes Solarized Dark and Solarized Light come from the official [Solarized web site](http://ethanschoonover.com/solarized)

The Obsidian theme was on my hard drive and I don't recall where it came from. If anyone knows, ping me and I'll link back to the author(s).

The Spacedust theme was created by [mhallendal](https://github.com/mhallendal/spacedust-theme) and ported to iTerm by [Couto](https://github.com/Couto)

The theme Mathias was created by [mathiasbynens](https://github.com/mathiasbynens/dotfiles)

The LiquidCarbon themes were created by [markcho](https://github.com/markcho/iTerm2_LiquidCarbon)

The NightLion themes were created by [Curvve Media](http://www.curvve.com/blog/category/themes/)

The Tomorrow themes were created by [chriskempson](https://github.com/chriskempson/tomorrow-theme/tree/master/iTerm2)

The Twilight theme was created by [stefri](https://gist.github.com/stefri/1183140)

The Teerb theme was created by [Teerb](https://gist.github.com/teerb/1360453)

The IR_Black theme was found [here](https://gist.github.com/meqif/1238378)

The Misterioso theme was created by [flooose](https://github.com/flooose/misterioso-iterm2)

The Hybrid theme was found [here](https://gist.github.com/luan/6362811)

The Thayer Bright theme was found [here](https://github.com/t3chnoboy/thayer-bright-iTerm)

The Spring theme was found [here](https://github.com/t3chnoboy/spring-iTerm)

The Smyck theme was found [here](https://github.com/hukl/Smyck-Color-Scheme)

The Cobalt2 theme was created by [wesbos](https://github.com/wesbos/Cobalt2-iterm)

The WarmNeon theme was ported from [PyCharm](http://www.jetbrains.com/pycharm/) by [firewut](https://github.com/firewut)

The SpaceGray theme was created by [ryentzer](https://github.com/ryentzer/SpaceGray-iTerm)

The Jellybeans theme was created by [qtpi](https://github.com/qtpi/Jellybeans.itermcolors)

The PaulMillr theme was created by [paulmillr](https://github.com/paulmillr/dotfiles/tree/master/terminal) and ported to iTerm by me

The Harper theme was created by [idleberg](https://github.com/idleberg/Harper-iTerm2)

The CLRS theme was created by [jasonlong](https://github.com/jasonlong/iterm-clrs)

The Dracula theme was created by [zenorocha](https://github.com/zenorocha/dracula-theme)

The themes AdventureTime, AlienBlood, BirdsOfParadise, Ciapre, CrayonPonyFish, DimmedMonokai, Earthsong, Elemental, FishTank, FrontEndDelight, FunForrest, Grape, Highway, IC_Green_PPL, IC_Orange_PPL, Lavandula, Medallion, MonaLisa, Ollie, Royal, SeaShells, Shaman, SoftServer, Sundried, ToyChest, Treehouse, and Urple were created by [zdj](https://github.com/zdj/themes/tree/master/iterm2)

The Japanesque theme was created by [aereal](https://github.com/aereal/dotfiles/blob/master/colors/Japanesque/Japanesque.itermcolors)

The Seti theme was created by [jesseweed](https://github.com/jesseweed/seti-syntax/) and ported to iTerm2 by [philduffy](https://github.com/philduffy/seti-iterm) and slightly modified to make the ANSI blacks have a little more contrast

The Hipster Green and Jackie Brown themes were created by [Unkulunkulu](https://github.com/Unkulunkulu)

The Chalk theme was created by [achalv](https://github.com/achalv/chalk)

The Pencil Dark and Pencil Light themes were created by [mattly](https://github.com/mattly/iterm-colors-pencil)

The Flat theme was created by [ahmetsulek](https://github.com/ahmetsulek/flat-terminal)

The Atom, Brogrammer, Glacier and Darkside themes were created by [bahlo](https://github.com/bahlo/iterm-colors)

The Afterglow theme was created by [yabatadesign](https://github.com/YabataDesign/afterglow-itermcolors)

The Broadcast theme was created by [vinkla](https://github.com/vinkla/broadcast-theme)

The Arthur, N0tch2k, Pnevma, Square, and Wryan themes were created by [baskerville](https://github.com/baskerville/iTerm-2-Color-Themes)

The Belafonte Day, Belafonte Night, Paraiso Dark, and C64 themes were created by [idleberg](https://github.com/idleberg)

The 3024 Day and 3024 Night themes were created by [0x3024](https://github.com/0x3024)

The Argonaut theme was created by [effkay](https://github.com/effkay/iTerm-argonaut)

The Espresso Libre theme was created by [jurgemaister](https://github.com/jurgemaister/Espresso-Libre)

The Hardcore theme was created by [hardcore](https://github.com/hardcore/iTerm-colors)

The Rippedcasts theme was created by [mdw123](https://github.com/mdw123/rippedcasts)

The Solorized Dark Higher Contrast theme was created by [heisters](https://gist.github.com/heisters/1015503)

The VibrantInk theme was created by [asanghi](https://github.com/asanghi/vibrantinklion)

The Wez theme was created by [wez](https://gist.github.com/wez/850268/)

The Wombat theme was created by [djoyner](https://github.com/djoyner/iTerm2-wombat)

The WildCherry theme was created by [mashaal](https://github.com/mashaal/wild-cherry)

The Flatland theme was created by [realchaseadams](http://www.snip2code.com/Snippet/148193/Flatland-color-scheme-for-iTerm2)

The Neutron theme was created by [Ch4s3](https://github.com/Ch4s3/iTerm2-Neutron)

The Fideloper theme was inspired by [Fideloper](http://fideloper.com/)

The Later This Evening theme was created by [vilhalmer](https://github.com/vilhalmer/System/tree/master/terminal-themes)

The Galaxy theme was created by [jglovier](https://github.com/jglovier/galaxy-theme-iterm)

The Slate theme was created by [deneshshan](https://github.com/deneshshan)

The SpaceGray Eighties and SpaceGray Eighties Dull themes were created by [mhkeller](https://github.com/mhkeller/spacegray-eighties-iterm)

The Borland theme was created by [delip](https://gist.github.com/delip/9e16c606d9331d69d681)

The Cobalt Neon theme was created by [vazquez](https://github.com/vazquez/cobalt-neon-iterm)

The AtelierSulphurpool theme was created by [atelierbram](http://atelierbram.github.io/syntax-highlighting/atelier-schemes/sulphurpool/)

The Batman, Spiderman, and The Hulk themes were created by [pyrophos](https://github.com/pyrophos)

The ENCOM theme was created by [Josh Braun](http://wideaperture.net)

The Floraverse theme was created by [papayakitty](http://floraverse.com/)

The Material and MaterialDark themes were created by [stoeffel](https://github.com/stoeffel/material-iterm)

The OceanicMaterial theme was created by [rahulpatel](https://github.com/rahulpatel)

The AtomOneLight theme was created by [iamstarkov](https://github.com/iamstarkov)

The Piatto Light theme was created by [kovv](https://github.com/kovv)

The DotGov theme was inspired by the color palette used in the [U.S. Web Design Standards](https://playbook.cio.gov/designstandards/visual-style/)

The DuoTone Dark theme was created by [chibicode](http://chibicode.com) based on [simurai](https://github.com/simurai)'s [duotone-dark](https://github.com/simurai/duotone-dark-syntax) Atom theme.

The JetBrains Darcula theme was created by [vitstr](https://github.com/vitstr)

The Bright Lights theme was created by [tw15egan](https://github.com/tw15egan)

The Ubuntu theme was inspired by default Ubuntu's console colors. Created by [Maximus](http://superuser.com/questions/497240/ubuntu-purple-terminal-colors-in-conemu) and ported to iTerm2 by [stepin](https://github.com/stepin).

If there are other color schemes you'd like to see included, drop me a line!

## Extra
###X11 Installation###
To install under the [X Window System](http://www.x.org/):

* Import the .xrdb file of the scheme you'd like to use:

        #include "/home/mbadolato/iTerm2-Color-Schemes/xrdb/Blazer.xrdb"

* Use the `#define`s provided by the imported .xrdb file:

        Rxvt*color0:       Ansi_0_Color
        Rxvt*color1:       Ansi_1_Color
        Rxvt*color2:       Ansi_2_Color
        Rxvt*color3:       Ansi_3_Color
        Rxvt*color4:       Ansi_4_Color
        Rxvt*color5:       Ansi_5_Color
        Rxvt*color6:       Ansi_6_Color
        Rxvt*color7:       Ansi_7_Color
        Rxvt*color8:       Ansi_8_Color
        Rxvt*color9:       Ansi_9_Color
        Rxvt*color10:      Ansi_10_Color
        Rxvt*color11:      Ansi_11_Color
        Rxvt*color12:      Ansi_12_Color
        Rxvt*color13:      Ansi_13_Color
        Rxvt*color14:      Ansi_14_Color
        Rxvt*color15:      Ansi_15_Color
        Rxvt*colorBD:      Bold_Color
        Rxvt*colorIT:      Italic_Color
        Rxvt*colorUL:      Underline_Color
        Rxvt*foreground:   Foreground_Color
        Rxvt*background:   Background_Color
        Rxvt*cursorColor:  Cursor_Color

        XTerm*color0:      Ansi_0_Color
        XTerm*color1:      Ansi_1_Color
        XTerm*color2:      Ansi_2_Color
        XTerm*color3:      Ansi_3_Color
        XTerm*color4:      Ansi_4_Color
        XTerm*color5:      Ansi_5_Color
        XTerm*color6:      Ansi_6_Color
        XTerm*color7:      Ansi_7_Color
        XTerm*color8:      Ansi_8_Color
        XTerm*color9:      Ansi_9_Color
        XTerm*color10:     Ansi_10_Color
        XTerm*color11:     Ansi_11_Color
        XTerm*color12:     Ansi_12_Color
        XTerm*color13:     Ansi_13_Color
        XTerm*color14:     Ansi_14_Color
        XTerm*color15:     Ansi_15_Color
        XTerm*colorBD:     Bold_Color
        XTerm*colorIT:     Italic_Color
        XTerm*colorUL:     Underline_Color
        XTerm*foreground:  Foreground_Color
        XTerm*background:  Background_Color
        XTerm*cursorColor: Cursor_Color

* Store the above snippets in a file and pass it in:

        $ xrdb -merge YOUR_FILE_CONTAINING_ABOVE_SNIPPETS

* Open new XTerm or Rxvt windows to see the changes.

* Adapt this procedure to other terminals as needed.

###Terminator color schemes###

Edit your Terminator configuration file (located in: `$HOME/.config/terminator/config`) and add the configurations for the theme(s) you'd like to use the ``[profiles]`` section. The `terminator/` directory contains the config snippets you'll need. Just paste the configurations into the `[profiles]` sections, and you're good to go!

At a minimum, this is all you need. You can customize the fonts and other aspects as well, if you wish. See the Terminator documentation for more details.

An example config file that includes the code snippet for the Symfonic theme would look like this:

```ini
[global_config]
    [keybindings]
    [profiles]
      [[default]]
        palette = "#1a1a1a:#f4005f:#98e024:#fa8419:#9d65ff:#f4005f:#58d1eb:#c4c5b5:#625e4c:#f4005f:#98e024:#e0d561:#9d65ff:#f4005f:#58d1eb:#f6f6ef"
        background_image = None
        use_system_font = False
        cursor_color = "#f6f7ec"
        foreground_color = "#c4c5b5"
        font = Source Code Pro Light 11
        background_color = "#1a1a1a"
      [[Symfonic]]
        palette = "#000000:#dc322f:#56db3a:#ff8400:#0084d4:#b729d9:#ccccff:#ffffff:#1b1d21:#dc322f:#56db3a:#ff8400:#0084d4:#b729d9:#ccccff:#ffffff"
        background_color = "#000000"
        cursor_color = "#dc322f"
        foreground_color = "#ffffff"
        background_image = None
    [layouts]
      [[default]]
        [[[child1]]]
          type = Terminal
          parent = window0
        [[[window0]]]
          type = Window
          parent = ""
    [plugins]
```

###Konsole color schemes###

Copy the themes from the `konsole` directory to `$HOME/.config/konsole`, restart Konsole and choose your new theme from the profile preferences window.

If you want to make the themes available to all users, copy the .colorscheme files to `/usr/share/konsole`.

###Terminal color schemes###
Just double click on selected theme in `terminal` directory

###Previewing color schemes###

[preview.rb](tools/preview.rb) is a simple script that allows you to preview
the color schemes without having to import them. It parses .itermcolors files
and applies the colors to the current session using [iTerm's proprietary
escape codes](https://iterm2.com/documentation-escape-codes.html). As noted in
the linked page, it doesn't run on tmux or screen.

```sh
# Apply AdventureTime scheme to the current session
tools/preview.rb schemes/AdventureTime.itermcolors

# Apply the schemes in turn.
# - Press any key to advance; hit CTRL-C or ESC to stop
tools/preview.rb schemes/*
```


----

iTerm Color Schemes | iTerm2 Color Schemes | iTerm 2 Color Schemes | iTerm Themes | iTerm2 Themes | iTerm 2 Themes

[![Analytics](https://ga-beacon.appspot.com/UA-30661340-2/mbadolato/iTerm2-Color-Schemes?pixel)](https://github.com/igrigorik/ga-beacon)
